# Goal Zero Yeti REST Api Library

Credit to Nicholas Andre for procuring the REST api info from Goal Zero: https://blog.nicholasandre.com/goal-zero-yeti-local-wifi-rest-api/

Thanks to Goal Zero for thinking of us techies by providing this.
